==> widelands-1%3A1.2.1-4.1-x86_64.pkg.tar.zst: usr/share/widelands/tribes/workers/amazons/liana_cutter/init.lua <==
push_textdomain("tribes")

local dirname = path.dirname (__file__)

wl.Descriptions():new_worker_type {
   name = "amazons_liana_cutter",
   -- TRANSLATORS: This is a worker name used in lists of workers
   descname = pgettext ("amazons_worker", "Liana Cutter"),
   icon = dirname .. "menu.png",
   vision_range = 2,

   buildcost = {
      amazons_carrier = 1,
      machete = 1
   },

   programs = {
      cut = {
         "findobject=attrib:tree radius:6",
         "walk=object",
         "playsound=sound/woodcutting/woodcutting priority:100% allow_multiple",
         "animate=work duration:4s",
         "playsound=sound/woodcutting/tree_falling priority:100%",
         "animate=work duration:1s",
         "createware=liana",
         "return"
      }
   },

   animation_directory = dirname,
   ware_hotspot = {0, 29},
   spritesheets = {
      walk = {
         directional = true,
         hotspot = {17, 28},
         fps = 15,
         frames = 30,
         columns = 6,
         rows = 5
      },
      walkload = {
         directional = true,
         hotspot = {17, 31},
         fps = 15,
         frames = 30,
         columns = 6,
         rows = 5
      },
      idle = {
         basename = "walk_se",
         hotspot = {17, 28},
         fps = 15,
         frames = 30,
         columns = 6,
         rows = 5
      },
      work = {
         hotspot = {19, 35},
         fps = 15,
         frames = 15,
         columns = 5,
         rows = 3
      },
   }
}

pop_textdomain()

==> widelands-1%3A1.3-3-x86_64.pkg.tar.zst: usr/share/widelands/tribes/workers/amazons/liana_cutter/init.lua <==
push_textdomain("tribes")

local dirname = path.dirname (__file__)

wl.Descriptions():new_worker_type {
   name = "amazons_liana_cutter",
   -- TRANSLATORS: This is a worker name used in lists of workers
   descname = pgettext ("amazons_worker", "Liana Cutter"),
   icon = dirname .. "menu.png",
   vision_range = 2,

   buildcost = {
      amazons_carrier = 1,
      machete = 1
   },

   programs = {
      cut = {
         -- steps from building to tree: 2-9
         -- min. worker time: 2 * 2 * 1.8 + 4 + 1 = 12.2 sec
         -- max. worker time: 2 * 9 * 1.8 + 4 + 1 = 37.4 sec
         "findobject=attrib:tree radius:6",
         "walk=object",
         "playsound=sound/woodcutting/woodcutting priority:100% allow_multiple",
         "animate=work duration:4s",
         "playsound=sound/woodcutting/tree_falling priority:100%",
         "animate=work duration:1s",
         "createware=liana",
         "return"
      }
   },

   animation_directory = dirname,
   ware_hotspot = {0, 29},
   spritesheets = {
      walk = {
         directional = true,
         hotspot = {17, 28},
         fps = 15,
         frames = 30,
         columns = 6,
         rows = 5
      },
      walkload = {
         directional = true,
         hotspot = {17, 31},
         fps = 15,
         frames = 30,
         columns = 6,
         rows = 5
      },
      idle = {
         basename = "walk_se",
         hotspot = {17, 28},
         fps = 15,
         frames = 30,
         columns = 6,
         rows = 5
      },
      work = {
         hotspot = {19, 35},
         fps = 15,
         frames = 15,
         columns = 5,
         rows = 3
      },
   }
}

pop_textdomain()
